/***************************************************************************
 *   Copyright (C) 2006 by Dave Parker                                     *
 *   drp@ezeedsl.co.uk                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "colour.h"
#include "surface.h"

// Colour class

// Value of transparent
const Colour Colour::NONE;

// Initialise to no colour
Colour::Colour ( void )
{
    colour = 0xFFFFFFFF;
}

// Set from pixel
Colour::Colour ( unsigned short c )
{
    scolour.r = ( c & 0xF800 ) >> 11;
    scolour.g = ( c & 0x07E0 ) >> 5;
    scolour.b = ( c & 0x001F );
    colour = c;
}


/**
 * Create colour od given RGB
 * @param s
 * @param r
 * @param g
 * @param b
 * @return
 */
Colour::Colour ( const Surface& s, Uint8 r, Uint8 g, Uint8 b )
{
    scolour.r = r;
    scolour.g = g;
    scolour.b = b;
    colour = SDL_MapRGB ( s.Format(), r, g, b );
}


/**
 * Get pixel value as a single value
 * @param
 * @return
 */
Uint32 Colour::Get ( void ) const
{
    return colour;
}

/**
 * Get pixel value as an SDL_Color
 * @param
 * @return
 */
SDL_Color Colour::SGet ( void ) const
{
    return scolour;
}
