//
// C++ Interface: menu
//
// Description:
//
//
// Author: Dave Parker <drp@ezeedsl.co.uk >, (C) 2006
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef MENU_H
#define MENU_H

#include <string>
#include <vector>

class Colour;
class Font;
class Surface;

/**
	Menu handler class
	A menu consists of a title, subtitle, options and a caption
*/
class Menu
{
public:
    Menu ( const std::string& t = "", const std::string& s = "" );

    ~Menu();
    void Add ( const std::string& option );
    void Render ( Surface &s, const Font &f, const Colour &fg, const Colour &bg, const Colour &hl );
    void Up();
    void Down();
    int GetOption();
    void SetCallback ( void ( *fn ) ( void* ), void* data );
    void DoAction();
    void SetOption ( int opt );
    void SetCaption ( const std::string& s );
    void SetSubtitle ( const std::string& s );

protected:
    std::vector<std::string> options;
    int max_len;
    int current_option;
    std::string title;
    std::string subtitle;
    void* callback_data;
    void ( *callback ) ( void* );
    std::string caption;
	
protected:
    void Centre ( Surface &s, const Font& f, const Colour &fg, const Colour &bg,
                  const std::string& text, int y, int len );
};

#endif
