/***************************************************************************
 *   Copyright (C) 2006 by Dave Parker                                     *
 *   drp@ezeedsl.co.uk                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "music.h"
#include <fstream>
#include <iostream>

using namespace std;

// Music class

/**
 * Load music from file
 * @param fn - Filename
 * @return
 */
Music::Music ( std::string fn ) : file ( fn ), volume ( 64 ), valid ( true )
{
    music = Mix_LoadMUS ( fn.c_str() );
    if ( music == NULL )
    {
        cerr << "Failed to open sound " << fn <<  " " << SDL_GetError() << endl;
        valid = false;
    }
}

Music::~Music()
{
    if ( music != NULL )
    {
        Mix_FreeMusic ( music );
    }
}

/**
 * Play sound
 * @return true for ok, false for error
*/
bool Music::Play()
{
    bool result = false;
    if ( music != NULL )
    {
        result = ( Mix_PlayMusic ( music, 0 ) == 0 );
    }
    return result;
}


/**
 * Set volume of music
 * @param v - volume
 */
void Music::SetVolume ( int v )
{
    if ( v < 0 ) v = 0;
    else if ( v > 128 ) v = 128;
    volume = v;
    if ( music != NULL )
    {

        Mix_VolumeMusic ( volume );
    }
}



/**
 * Increase volume of sound
 */
void Music::VolumeUp()
{
    SetVolume ( volume + 8 );
}

/**
 * Decrease volume of sound
 */
void Music::VolumeDown()
{
    SetVolume ( volume - 8 );
}


/**
 * Get volume of music
 * @return Volume
 */
int Music::GetVolume()
{
    return volume;
}

string Music::GetFile()
{
    return file;
}

bool Music::IsValid()
{
    return valid;
}
