//
// C++ Implementation: surface
//
// Description:
//
//
// Author: Dave Parker <drp@ezeedsl.co.uk >, (C) 2006
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "surface.h"

/**
 * Default constructor
 * @return
 */
Surface::Surface()
{
}


/**
 * Destructor
 * @return
 */
Surface::~Surface()
{
}

/**
 * Put pixel of colour c at x,y
 * If colour is NONE - no pixel is plotted
 * @param x - X position
 * @param y - Y position
 * @param c - pixel colour
 */
void Surface::PutPixel ( int x, int y, const Colour& c )
{
    if ( x >=0 && x < surface->w && y >=0 && y < surface->h &&
            c != Colour::NONE )
    {
        unsigned short* dst = static_cast<unsigned short*> ( surface->pixels );
        dst[y * surface->pitch/sizeof ( unsigned short ) + x] = c.Get();
    }
}

/**
 *
 * @param x - X position
 * @param y - Y position
 * @return colour of pixel
 */
unsigned short Surface::GetPixel ( int x, int y )
{
    unsigned short* p = reinterpret_cast<unsigned short*> ( surface->pixels );
    return p[y * surface->pitch/sizeof ( unsigned short ) + x];
}

/**
 * Draw a filled rectangle
 * @param x - X position
 * @param y - Y position
 * @param w - width
 * @param h - height
 * @param c - colour
 */
void Surface::Rect ( int x, int y, int w, int h, const Colour& c )
{
    SDL_Rect r;
    r.x = x;
    r.y = y;
    r.w = w;
    r.h = h;
    SDL_FillRect ( surface, &r, c.Get() );
}


/**
 * Get pixel format
 * @param
 * @return
 */
SDL_PixelFormat* Surface::Format ( void ) const
{
    return surface->format;
}


/**
 * Blit Surface to another Surface
 * @param dest - destination Surface
 * @param x
 * @param y
 */
void Surface::Put ( Surface &dest, int x, int y )
{
    SDL_Rect dstr;
    dstr.x = x;
    dstr.y = y;
    SDL_BlitSurface ( surface, NULL, dest.GetSurface(), &dstr );
}


void Surface::PutBlended ( Surface& dest, int x, int y, const Colour& transparent )
{
    int w = surface->w;
    int h = surface->h;

    for ( int i = 0; i < w; i++ )
    {
        for ( int j = 0; j < h; j++ )
        {
            unsigned short c = GetPixel ( i,j );
            if ( c != transparent.Get() )
            {
                dest.PutPixel ( x+i, y+j, c );
            }
        }
    }
}

SDL_Surface* Surface::GetSurface( )
{
    return surface;
}


void Surface::SetSurface ( SDL_Surface* theValue )
{
    surface = theValue;
}
