/***************************************************************************
 *   Copyright (C) 2006 by Dave Parker                                     *
 *   drp@ezeedsl.co.uk                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef PIECE_H
#define PIECE_H

#include <string>
#include "board.h"
#include "chesscommon.h"

class Image;
class Screen;

/**
 	Piece handler
*/
class Piece
{
public:
    Piece ( const std::string& i, PieceType t, Side s );
    Piece ( const Piece& p );
    virtual ~Piece();
    void Draw ( Screen& s, int x, int y );
    virtual void Move ( Board& board, int x1, int y1, int x2, int y2 );
    virtual bool CheckPromote ( int x1, int y1, int x2, int y2 );
    virtual Piece* Clone() const = 0;
    Side GetSide()
    {
        return side;
    }
    PieceType GetType()
    {
        return type;
    }
    void SetImage ( const std::string& fn ) ;

protected:
    std::string file_name;
    PieceType type;
    Side side;
    Image* image;
};

/**
 	Rook
*/
class Rook : public Piece
{
public:
    Rook ( Side s, const std::string &i );
    virtual Piece* Clone() const
    {
        return new Rook ( *this );
    }
};

/**
 	Knight
*/
class Knight : public Piece
{
public:
    Knight ( Side s, const std::string &i );
    virtual Piece* Clone() const
    {
        return new Knight ( *this );
    }
};

/**
 	Bishop
*/
class Bishop : public Piece
{
public:
    Bishop ( Side s, const std::string &i );
    virtual Piece* Clone() const
    {
        return new Bishop ( *this );
    }
};

/**
 	Queen
*/
class Queen : public Piece
{
public:
    Queen ( Side s, const std::string &i );
    virtual Piece* Clone() const
    {
        return new Queen ( *this );
    }
};

/**
 	King
*/
class King : public Piece
{
public:
    King ( Side s, const std::string &i );
    virtual Piece* Clone() const
    {
        return new King ( *this );
    }
    virtual void Move ( Board& board, int x1, int y1, int x2, int y2 );
};

/**
 	Pawn
*/
class Pawn : public Piece
{
public:
    Pawn ( Side s, const std::string &i );
    virtual void Move ( Board& board, int x1, int y1, int x2, int y2 );
    virtual Piece* Clone() const
    {
        return new Pawn ( *this );
    }
    virtual bool CheckPromote ( int x1, int y1, int x2, int y2 );
};

#endif

